==> jc-1.4.0.tar.gz: java/util/IdentityHashMap__24IdentityIterator.h <==
// class java.util.IdentityHashMap$IdentityIterator

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 935d50153a2e11a8 java_util_IdentityHashMap__24IdentityIterator

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_util_IdentityHashMap__24IdentityIterator_H_
#define _JC_java_util_IdentityHashMap__24IdentityIterator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_IdentityHashMap$object;

// Typedefs
typedef struct _jc_java_util_IdentityHashMap__24IdentityIterator$sub_refs	_jc_java_util_IdentityHashMap__24IdentityIterator$sub_refs;
typedef struct _jc_java_util_IdentityHashMap__24IdentityIterator$sub_nonrefs	_jc_java_util_IdentityHashMap__24IdentityIterator$sub_nonrefs;
typedef struct _jc_java_util_IdentityHashMap__24IdentityIterator$refs	_jc_java_util_IdentityHashMap__24IdentityIterator$refs;
typedef struct _jc_java_util_IdentityHashMap__24IdentityIterator$nonrefs	_jc_java_util_IdentityHashMap__24IdentityIterator$nonrefs;
typedef struct _jc_java_util_IdentityHashMap__24IdentityIterator$object	_jc_java_util_IdentityHashMap__24IdentityIterator$object;

typedef const struct _jc_java_util_IdentityHashMap__24IdentityIterator$vmethods	_jc_java_util_IdentityHashMap__24IdentityIterator$vmethods;
typedef const struct _jc_java_util_IdentityHashMap__24IdentityIterator$vtable	_jc_java_util_IdentityHashMap__24IdentityIterator$vtable;
typedef const struct _jc_java_util_IdentityHashMap__24IdentityIterator$vtype	_jc_java_util_IdentityHashMap__24IdentityIterator$vtype;

// Constructors
extern void _jc_java_util_IdentityHashMap__24IdentityIterator$method$_init$ff992f6c22a57c02(_jc_env *, struct _jc_java_util_IdentityHashMap__24IdentityIterator$object *, struct _jc_java_util_IdentityHashMap$object *, jint);

// Virtual methods
extern jboolean _jc_java_util_IdentityHashMap__24IdentityIterator$method$hasNext$fb0bd5e38c59ddcd(_jc_env *, struct _jc_java_util_IdentityHashMap__24IdentityIterator$object *);
extern struct _jc_java_lang_Object$object *_jc_java_util_IdentityHashMap__24IdentityIterator$method$next$05874f79a1cf66ea(_jc_env *, struct _jc_java_util_IdentityHashMap__24IdentityIterator$object *);
extern void _jc_java_util_IdentityHashMap__24IdentityIterator$method$remove$fd50149979e1f350(_jc_env *, struct _jc_java_util_IdentityHashMap__24IdentityIterator$object *);
extern void _jc_java_util_IdentityHashMap__24IdentityIterator$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_java_util_IdentityHashMap__24IdentityIterator$object *);

// Virtual method descriptors
extern _jc_method _jc_java_util_IdentityHashMap__24IdentityIterator$method_info$hasNext$fb0bd5e38c59ddcd;
extern _jc_method _jc_java_util_IdentityHashMap__24IdentityIterator$method_info$next$05874f79a1cf66ea;
extern _jc_method _jc_java_util_IdentityHashMap__24IdentityIterator$method_info$remove$fd50149979e1f350;
extern _jc_method _jc_java_util_IdentityHashMap__24IdentityIterator$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_java_util_IdentityHashMap__24IdentityIterator$vmethods {
	jboolean	(*hasNext$fb0bd5e38c59ddcd)(_jc_env *, struct _jc_java_util_IdentityHashMap__24IdentityIterator$object *);
	struct _jc_java_lang_Object$object	*(*next$05874f79a1cf66ea)(_jc_env *, struct _jc_java_util_IdentityHashMap__24IdentityIterator$object *);
	void	(*remove$fd50149979e1f350)(_jc_env *, struct _jc_java_util_IdentityHashMap__24IdentityIterator$object *);
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_java_util_IdentityHashMap__24IdentityIterator$object *);
};

// Vtable
struct _jc_java_util_IdentityHashMap__24IdentityIterator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_IdentityHashMap__24IdentityIterator$vmethods	java_util_IdentityHashMap__24IdentityIterator;
};

// Vtype
struct _jc_java_util_IdentityHashMap__24IdentityIterator$vtype {
	_jc_type			type;
	_jc_java_util_IdentityHashMap__24IdentityIterator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_IdentityHashMap__24IdentityIterator$sub_refs {
	struct _jc_java_util_IdentityHashMap$object	*this;
};

// Reference instance fields (object)
struct _jc_java_util_IdentityHashMap__24IdentityIterator$refs {
    _jc_java_util_IdentityHashMap__24IdentityIterator$sub_refs	java_util_IdentityHashMap__24IdentityIterator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_IdentityHashMap__24IdentityIterator$sub_nonrefs {
	jint	type;
	jint	knownMod;
	jint	count;
	jint	loc;
};

// Non-reference instance fields (object)
struct _jc_java_util_IdentityHashMap__24IdentityIterator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_IdentityHashMap__24IdentityIterator$sub_nonrefs	java_util_IdentityHashMap__24IdentityIterator;
};

// Object instance structure
struct _jc_java_util_IdentityHashMap__24IdentityIterator$object {
	_jc_java_util_IdentityHashMap__24IdentityIterator$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_IdentityHashMap__24IdentityIterator$vtype	*vtype;
	_jc_java_util_IdentityHashMap__24IdentityIterator$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_IdentityHashMap__24IdentityIterator$vtype _jc_java_util_IdentityHashMap__24IdentityIterator$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_IdentityHashMap__24IdentityIterator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_IdentityHashMap__24IdentityIterator$class_object;

#endif	/* _JC_java_util_IdentityHashMap__24IdentityIterator_H_ */

==> jc-1.4.6.tar.gz: java/util/IdentityHashMap__24IdentityIterator.h <==
// class java.util.IdentityHashMap$IdentityIterator

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 935d50153a2e11a8 java_util_IdentityHashMap__24IdentityIterator

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_util_IdentityHashMap__24IdentityIterator_H_
#define _JC_java_util_IdentityHashMap__24IdentityIterator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_IdentityHashMap$object;

// Typedefs
typedef struct _jc_java_util_IdentityHashMap__24IdentityIterator$sub_refs	_jc_java_util_IdentityHashMap__24IdentityIterator$sub_refs;
typedef struct _jc_java_util_IdentityHashMap__24IdentityIterator$sub_nonrefs	_jc_java_util_IdentityHashMap__24IdentityIterator$sub_nonrefs;
typedef struct _jc_java_util_IdentityHashMap__24IdentityIterator$refs	_jc_java_util_IdentityHashMap__24IdentityIterator$refs;
typedef struct _jc_java_util_IdentityHashMap__24IdentityIterator$nonrefs	_jc_java_util_IdentityHashMap__24IdentityIterator$nonrefs;
typedef struct _jc_java_util_IdentityHashMap__24IdentityIterator$object	_jc_java_util_IdentityHashMap__24IdentityIterator$object;

typedef const struct _jc_java_util_IdentityHashMap__24IdentityIterator$vmethods	_jc_java_util_IdentityHashMap__24IdentityIterator$vmethods;
typedef const struct _jc_java_util_IdentityHashMap__24IdentityIterator$vtable	_jc_java_util_IdentityHashMap__24IdentityIterator$vtable;
typedef const struct _jc_java_util_IdentityHashMap__24IdentityIterator$vtype	_jc_java_util_IdentityHashMap__24IdentityIterator$vtype;

// Constructors
extern void _jc_java_util_IdentityHashMap__24IdentityIterator$method$_init$ff992f6c22a57c02(_jc_env *, struct _jc_java_util_IdentityHashMap__24IdentityIterator$object *, struct _jc_java_util_IdentityHashMap$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_java_util_IdentityHashMap__24IdentityIterator$method$hasNext$fb0bd5e38c59ddcd(_jc_env *, struct _jc_java_util_IdentityHashMap__24IdentityIterator$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_java_util_IdentityHashMap__24IdentityIterator$method$next$05874f79a1cf66ea(_jc_env *, struct _jc_java_util_IdentityHashMap__24IdentityIterator$object *) _JC_JCNI_ATTR;
extern void _jc_java_util_IdentityHashMap__24IdentityIterator$method$remove$fd50149979e1f350(_jc_env *, struct _jc_java_util_IdentityHashMap__24IdentityIterator$object *) _JC_JCNI_ATTR;
extern void _jc_java_util_IdentityHashMap__24IdentityIterator$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_java_util_IdentityHashMap__24IdentityIterator$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_util_IdentityHashMap__24IdentityIterator$method_info$hasNext$fb0bd5e38c59ddcd;
extern _jc_method _jc_java_util_IdentityHashMap__24IdentityIterator$method_info$next$05874f79a1cf66ea;
extern _jc_method _jc_java_util_IdentityHashMap__24IdentityIterator$method_info$remove$fd50149979e1f350;
extern _jc_method _jc_java_util_IdentityHashMap__24IdentityIterator$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_java_util_IdentityHashMap__24IdentityIterator$vmethods {
	jboolean	(*hasNext$fb0bd5e38c59ddcd)(_jc_env *, struct _jc_java_util_IdentityHashMap__24IdentityIterator$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*next$05874f79a1cf66ea)(_jc_env *, struct _jc_java_util_IdentityHashMap__24IdentityIterator$object *) _JC_JCNI_ATTR;
	void	(*remove$fd50149979e1f350)(_jc_env *, struct _jc_java_util_IdentityHashMap__24IdentityIterator$object *) _JC_JCNI_ATTR;
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_java_util_IdentityHashMap__24IdentityIterator$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_util_IdentityHashMap__24IdentityIterator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_IdentityHashMap__24IdentityIterator$vmethods	java_util_IdentityHashMap__24IdentityIterator;
};

// Vtype
struct _jc_java_util_IdentityHashMap__24IdentityIterator$vtype {
	_jc_type			type;
	_jc_java_util_IdentityHashMap__24IdentityIterator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_IdentityHashMap__24IdentityIterator$sub_refs {
	struct _jc_java_util_IdentityHashMap$object	*this;
};

// Reference instance fields (object)
struct _jc_java_util_IdentityHashMap__24IdentityIterator$refs {
    _jc_java_util_IdentityHashMap__24IdentityIterator$sub_refs	java_util_IdentityHashMap__24IdentityIterator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_IdentityHashMap__24IdentityIterator$sub_nonrefs {
	jint	type;
	jint	knownMod;
	jint	count;
	jint	loc;
};

// Non-reference instance fields (object)
struct _jc_java_util_IdentityHashMap__24IdentityIterator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_IdentityHashMap__24IdentityIterator$sub_nonrefs	java_util_IdentityHashMap__24IdentityIterator;
};

// Object instance structure
struct _jc_java_util_IdentityHashMap__24IdentityIterator$object {
	_jc_java_util_IdentityHashMap__24IdentityIterator$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_IdentityHashMap__24IdentityIterator$vtype	*vtype;
	_jc_java_util_IdentityHashMap__24IdentityIterator$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_IdentityHashMap__24IdentityIterator$vtype _jc_java_util_IdentityHashMap__24IdentityIterator$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_IdentityHashMap__24IdentityIterator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_IdentityHashMap__24IdentityIterator$class_object;

#endif	/* _JC_java_util_IdentityHashMap__24IdentityIterator_H_ */
